@@ -23,18 +23,18 @@ class Client(object):
         self.url = "https://db.neelr.dev/api/%s/" % token
     
     def store(self, key, data):
-        r = requests.post(self.url + key, data=jsonpickle.dumps(data))
+        r = requests.post(self.url + key, data={'data':jsonpickle.dumps(data)})
         return (r.status_code == 201), r.content.decode()
     
     def retrieve(self, key):
         r = requests.get(self.url + key)
         if r.status_code == 404:
             return None
-        return jsonpickle.loads(r.content.decode())
+        return jsonpickle.loads(r.json()['data'])
     
     def delete(self, key):
         r = requests.delete(self.url + key)
         return r.status_code == 204
     
     def pull(self):
-        return requests.get(self.url).json()
\ No newline at end of file
+        return {x:jsonpickle.loads(i) for x,i in requests.get(self.url).json()['data'].items()}
\ No newline at end of file
